﻿using MediatR;
using Microsoft.Extensions.Logging;
using NetworkResurrector.Api.Domain.Constants;
using NetworkResurrector.Api.Domain.Repositories;
using NetworkResurrector.Api.PublishedLanguage.Commands;
using NetworkResurrector.Api.PublishedLanguage.Events;
using NetworkResurrector.Server.Wrapper.Services;
using System;
using System.Threading;
using System.Threading.Tasks;

namespace NetworkResurrector.Api.Application.CommandHandlers
{
    public class WakeMachineHandler : IRequestHandler<WakeMachine, MachineWaked>
    {
        private readonly ILogger<WakeMachineHandler> _logger;
        private readonly IResurrectorService _resurrectorService;
        private readonly INetworkRepository _repository;

        public WakeMachineHandler(ILogger<WakeMachineHandler> logger, IResurrectorService resurrectorService, INetworkRepository repository)
        {
            _logger=logger;
            _resurrectorService=resurrectorService;
            _repository=repository;
        }

        public async Task<MachineWaked> Handle(WakeMachine command, CancellationToken cancellationToken)
        {
            _logger.LogDebug($"Start waking up machine {command.MachineId}");
            var machine = await _repository.GetMachine(command.MachineId);
            var powerConfiguration = await _repository.GetPowerActionConfiguration(command.MachineId, PowerActions.WAKE);

            //log activity

            MachineWaked result;
            switch (powerConfiguration.Performer.PerformerCode)
            {
                case PowerActionPerformers.NETWORK_RESURRECTOR_SERVER:
                    var wakeResult = await _resurrectorService.Wake(machine.MACAddress);
                    result = new MachineWaked(wakeResult.Success, wakeResult.Status);
                    _logger.LogDebug($"Machine {command.MachineId} wake up finished. Success: {result.Success}; Status: {result.Status}");
                    break;

                default:
                    throw new Exception($"Power action performer {powerConfiguration.Performer.PerformerCode} is not implemented.");
            }

            return result;
        }
    }
}
